# System configuration module
Module used for system configuration based on config file. Reads config yaml file
and return it on a dictionary. It also allows to read sections of configuration
files.

Co-authors:
[Roberto Aldea](https://pypi.org/user/Raldea/), 
[Javier Sanz](https://pypi.org/user/javibu13/),
[Marius Crisan](https://pypi.org/user/mariuscrsn/)
